@@ -154,9 +154,9 @@ class GoSlideCloud:
             aiohttp.client_exceptions.ClientConnectionError,
             aiohttp.client_exceptions.ClientConnectorError,
         ) as err:
-            raise ClientConnectionError(str(err))
+            raise ClientConnectionError(str(err)) from None
         except asyncio.TimeoutError as err:
-            raise ClientTimeoutError("Connection Timeout")
+            raise ClientTimeoutError("Connection Timeout") from None
 
     async def _request(self, reqtype, urlsuffix, data=None):
         """Retry authentication around dorequest."""
@@ -297,13 +297,13 @@ class GoSlideCloud:
         #   "data": {
         #     "board_rev": 1,
         #     "calib_time": 10239,
-        #     "curtain_type": 0,
-        #     "device_name": "Living Room",
+        #     "curtain_type": 0, # deprecated
+        #     "device_name": "Living Room", # deprecated
         #     "mac": "300000000000",
         #     "pos": 0.0,
         #     "slide_id": "slide_300000000000",
         #     "touch_go": true,
-        #     "zone_name": ""
+        #     "zone_name": "" # deprecated
         #   },
         #   "error": null
         # }
@@ -317,6 +317,23 @@ class GoSlideCloud:
         _LOGGER.error("Missing key 'data' in JSON=%s", json.dumps(result))
         return None
 
+    async def slide_config(self, slideid):
+        """Retrieve the slide configuration."""
+        # The format is:
+        # {
+        #   tbd
+        #   "error": null
+        # }
+        if not await self._checkauth():
+            return None
+
+        result = await self._request("GET", "slides/{}".format(slideid))
+        if result and "data" in result:
+            return result["data"]
+
+        _LOGGER.error("Missing key 'data' in JSON=%s", json.dumps(result))
+        return None
+
     async def slide_get_position(self, slideid):
         """Retrieve the slide position."""
         result = await self.slide_info(slideid)
@@ -546,9 +563,9 @@ class GoSlideLocal:
             aiohttp.client_exceptions.ClientConnectionError,
             aiohttp.client_exceptions.ClientConnectorError,
         ) as err:
-            raise ClientConnectionError(str(err))
+            raise ClientConnectionError(str(err)) from None
         except asyncio.TimeoutError as err:
-            raise ClientTimeoutError("Connection Timeout")
+            raise ClientTimeoutError("Connection Timeout") from None
 
     async def _request(self, hostname, password, reqtype, uri, data=None):
         """Digest authentication using dorequest."""
@@ -572,7 +589,9 @@ class GoSlideLocal:
             # The resptext contains the WWW-Authentication header
             auth = self._make_digest_auth("user", password, reqtype, uri, resptext)
 
-            respstatus, resptext = await self._dorequest(reqtype, url, auth)
+            respstatus, resptext = await self._dorequest(
+                reqtype, url, digestauth=auth, data=data
+            )
 
             if respstatus == 200:
                 return resptext
@@ -664,17 +683,17 @@ class GoSlideLocal:
         if not await self._slide_exist(hostname):
             return False
 
-        result = await self._request(
+        resp = await self._request(
             hostname, self._slides[hostname], "POST", "/rpc/Slide.SetPos", {"pos": pos}
         )
         return bool(resp)
 
-    async def slide_open(self, slideid):
+    async def slide_open(self, hostname):
         """Open a slide."""
         if not await self._slide_exist(hostname):
             return False
 
-        result = await self._request(
+        resp = await self._request(
             hostname, self._slides[hostname], "POST", "/rpc/Slide.SetPos", {"pos": 0.0}
         )
         return bool(resp)
@@ -684,7 +703,7 @@ class GoSlideLocal:
         if not await self._slide_exist(hostname):
             return False
 
-        result = await self._request(
+        resp = await self._request(
             hostname, self._slides[hostname], "POST", "/rpc/Slide.SetPos", {"pos": 1.0}
         )
         return bool(resp)
@@ -694,7 +713,7 @@ class GoSlideLocal:
         if not await self._slide_exist(hostname):
             return False
 
-        result = await self._request(
+        resp = await self._request(
             hostname, self._slides[hostname], "POST", "/rpc/Slide.Stop"
         )
         return bool(resp)
@@ -704,7 +723,7 @@ class GoSlideLocal:
         if not await self._slide_exist(hostname):
             return False
 
-        result = await self._request(
+        resp = await self._request(
             hostname, self._slides[hostname], "POST", "/rpc/Slide.Calibrate"
         )
         return bool(resp)
@@ -714,7 +733,7 @@ class GoSlideLocal:
         if not await self._slide_exist(hostname):
             return False
 
-        result = await self._request(
+        resp = await self._request(
             hostname,
             self._slides[hostname],
             "POST",
